Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1096)

Unified Diff: chrome/browser/extensions/api/downloads/downloads_api_unittest.cc

Issue 11359217: Move scoped_temp_dir from base to base/files (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/api/downloads/downloads_api_unittest.cc
diff --git a/chrome/browser/extensions/api/downloads/downloads_api_unittest.cc b/chrome/browser/extensions/api/downloads/downloads_api_unittest.cc
index ad2605ed231e0d6942cc8e23485122e3cce1c6f7..7c0117fe7d451def12d0ea81afed1d39066c46a0 100644
--- a/chrome/browser/extensions/api/downloads/downloads_api_unittest.cc
+++ b/chrome/browser/extensions/api/downloads/downloads_api_unittest.cc
@@ -5,10 +5,10 @@
#include <algorithm>
#include "base/file_util.h"
+#include "base/files/scoped_temp_dir.h"
#include "base/json/json_reader.h"
#include "base/json/json_writer.h"
#include "base/message_loop.h"
-#include "base/scoped_temp_dir.h"
#include "base/stl_util.h"
#include "base/stringprintf.h"
#include "chrome/browser/download/download_file_icon_extractor.h"
@@ -535,7 +535,7 @@ class DownloadExtensionTest : public ExtensionApiTest {
downloads_directory_.path());
}
- ScopedTempDir downloads_directory_;
+ base::ScopedTempDir downloads_directory_;
const extensions::Extension* extension_;
Browser* incognito_browser_;
Browser* current_browser_;
@@ -1018,7 +1018,7 @@ IN_PROC_BROWSER_TEST_F(DownloadExtensionTest,
EXPECT_STREQ("hello", result_string.c_str());
}
// The temporary files should be cleaned up when the ScopedTempDir is removed.
}
// Test passing the empty query to search().
« no previous file with comments | « chrome/browser/download/save_page_browsertest.cc ('k') | chrome/browser/extensions/api/file_system/file_system_apitest.cc » ('j') | no next file with comments »
@@ -1018,7 +1018,7 @@ IN_PROC_BROWSER_TEST_F(DownloadExtensionTest,
EXPECT_STREQ("hello", result_string.c_str());
}
- // The temporary files should be cleaned up when the ScopedTempDir is removed.
+ // The temporary files should be cleaned up when the base::ScopedTempDir is removed.
}
// Test passing the empty query to search().

Powered by Google App Engine
This is Rietveld 408576698